=========================
scikit-nano documentation
=========================

:Release: |release|
:Date: |today|

.. include:: ../../README.rst
   :start-line: 4
   :end-line: 6

.. toctree::
   :maxdepth: 1

   getting_started.rst

.. toctree::
   :maxdepth: 2

   tutorial/index.rst

.. toctree::
   :maxdepth: 1

   contribute.rst
   credits.rst
   release.rst


.. _reference:

=========
Reference
=========

.. toctree::
   :maxdepth: 1

   chemistry.rst
   nanogen.rst
   nanogen_gui.rst
   scripts.rst
   structure_io.rst
   tools.rst


* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
